@@ -11,10 +11,8 @@ def main():
 
     sys.path.append('src/YamlBase')
 
-    with open('src/yamlbase/descriptions_cfg.yaml') as f:
-        descriptions = yaml.load(f)
-
-    parser = argparse.ArgumentParser(description=descriptions['arg_parse_descr'])
+    parser = argparse.ArgumentParser(description='This utility allows you to manage changes to the database using '
+                                                 'configurations')
     parser.add_argument('-cfg_db', action='store', dest='cfg_path',
                         help='Path to yaml file with DB config')
     parser.add_argument('-cfg_action', action='store', dest='action',
